# Supporters

Development of this version of OctoPrint wouldn't have been possible without
[the financial support by the community](https://support.octoprint.org) -
thanks to everyone who contributed!

## Patrons & Sponsors

  * 3D-TECH
  * 3DPrinterOS
  * Accalia Elementia
  * Al Mucci
  * Alex Young
  * Anthony Gainsborough
  * Ash King
  * BigTreeTech
  * Boris Hussein
  * Brad Jackson
  * Bradford Benn
  * Brandon Robertson
  * Bruce Meyer
  * Charles Morgan
  * Chloe Martin
  * Chris Heerschap
  * Christian Petropolis
  * Christian Wolf
  * Christian Würthner
  * Christoph Sigrist
  * Christopher Heiny
  * Cognite Solutions
  * Coltarus Halo
  * CooperSpartan
  * David OMeara
  * David Pitman
  * DeltaMaker 3D Printers
  * Dennis Breining
  * Dima Gorbenko
  * Doc
  * Dr. Frank Wester
  * Ed Crump
  * Erik Ableson
  * Ernesto Martinez
  * Fiberpunk
  * Franziska Kunsmann
  * George Jeng
  * Happy House
  * Hog Duske
  * Jacob Renstrom
  * James Fryman
  * Jason Kitchens
  * Jay Moran
  * JCsGotThis
  * Jeff Moe
  * Jeremy Cole
  * John Cassel
  * Julian Melo
  * Justin Kaufman
  * Kaile Riser
  * kantlivelong@gmail.com
  * Kazuhiro Ogura
  * Keenan Newton
  * Kenneth Jiang
  * Kevin Luff
  * Khaled Allen
  * Kureemii
  * Kurt Wubbels
  * Lachlan Bell
  * Laser-Lance
  * Lefteris Lertas
  * LulzBot
  * Makespace Madrid
  * Marco van Dijk
  * Mark Greenwald
  * Mark Robards
  * Mark Walker
  * Martin
  * Martin Schmitt
  * mcbriers
  * Michael Aumock
  * Michael Badagliacco
  * Michael Duergner
  * Mike Labanov
  * Mosaic Manufacturing
  * Nick Chestnut
  * Norman Jaffe
  * Obico
  * Paul McMaster
  * Randy C. Will
  * Ranjib Dey
  * Richard Stocks
  * Rik KM
  * Robert Gusek
  * Sebastien Andrivet
  * SimplyPrint
  * Sinie47
  * Stefan Krister
  * TheWebMachine
  * Tideline 3D
  * Ulrich Kempken

and 3192 more wonderful people pledging on the [Patreon campaign](https://patreon.com/foosel), on [GitHub Sponsors](https://github.com/users/foosel/sponsorship), via [Ko-fi](https://ko-fi.com/octoprint) or [Donorbox](https://donorbox.org/support-octoprint?recurring=true)!
